# features

+ (?) Add description content in pypi
+ (?) Add support for completion in shell via **argcomplete**
+ (?) Allow `@ea.command("new-name")` for functions with too long name
+ (?) customized help information with colorful messages
+ (?) Filter functions for showing available functions in CLI-executor mode
+ (?) resolve type by default value, but still restrained to generic python types

## done
+ (2024-11-29) add actions for __main__ entry, that is, run a function even without statement "import easyarg", just run the function
